# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LocalServerInfo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='LocalServerInfo.proto',
  package='com.eufylife.smarthome.protobuftool',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x15LocalServerInfo.proto\x12#com.eufylife.smarthome.protobuftool\"\xe6\r\n\x12LocalServerMessage\x12\x11\n\tmagic_num\x18\x01 \x01(\r\x12\x11\n\tlocalcode\x18\x02 \x01(\t\x12V\n\x01\x61\x18\x03 \x01(\x0b\x32I.com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessageH\x00\x12U\n\x01\x62\x18\x04 \x01(\x0b\x32H.com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessageH\x00\x12T\n\x01\x63\x18\x05 \x01(\x0b\x32G.com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessageH\x00\x12S\n\x01\x64\x18\x06 \x01(\x0b\x32\x46.com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessageH\x00\x1a\xb2\x01\n\x11PingPacketMessage\x12\x66\n\x04type\x18\x01 \x01(\x0e\x32X.com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage.PingPacketType\"5\n\x0ePingPacketType\x12\x10\n\x0cPING_REQUEST\x10\x00\x12\x11\n\rPING_RESPONSE\x10\x01\x1a\xf3\x05\n\x10OtaPacketMessage\x12\x64\n\x04type\x18\x01 \x01(\x0e\x32V.com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaPacketType\x12\x14\n\x0cotafile_size\x18\x02 \x01(\r\x12o\n\x08ota_data\x18\x03 \x01(\x0b\x32].com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage\x12\x61\n\x05\x63\x61use\x18\x04 \x01(\x0e\x32R.com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.FailCause\x1aO\n\x14OtaUpdateDataMessage\x12\x12\n\nadr_offset\x18\x01 \x01(\r\x12\x15\n\rpacket_length\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xce\x01\n\rOtaPacketType\x12\x1b\n\x17REQUEST_UPDATE_FIRMWARE\x10\x01\x12\x11\n\rPERMIT_UPDATE\x10\x02\x12\x18\n\x14OTA_UPDATE_DATA_SEND\x10\x03\x12\x16\n\x12UPDATE_DATA_VERIFY\x10\x04\x12\x14\n\x10OTA_UPDATE_ABORT\x10\x05\x12\x17\n\x13OTA_COMPLETE_NOTIFY\x10\x06\x12\x14\n\x10OTA_STATUS_FAILD\x10\x07\x12\x16\n\x12OTA_STATUS_SUCCESS\x10\x08\"m\n\tFailCause\x12\x17\n\x13\x45RASE_SECTION_FAILD\x10\x01\x12\x15\n\x11\x44\x41TA_OFFSET_ERROR\x10\x02\x12\x15\n\x11SWITCH_SIGN_FAILD\x10\x03\x12\x19\n\x15\x42RUN_UNFINISHED_ERROR\x10\x04\x1a\xdb\x01\n\x0fUserDataMessage\x12\x62\n\x04type\x18\x01 \x01(\x0e\x32T.com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage.UserDataType\x12\x10\n\x08usr_data\x18\x02 \x01(\x0c\"R\n\x0cUserDataType\x12\x14\n\x10sendUsrDataToDev\x10\x00\x12\x14\n\x10getDevStatusData\x10\x01\x12\x16\n\x12sendStausDataToApp\x10\x02\x1a\xba\x01\n\x0e\x44\x65vinfoMessage\x12`\n\x04type\x18\x01 \x01(\x0e\x32R.com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage.DevInfoType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"8\n\x0b\x44\x65vInfoType\x12\x13\n\x0fREQUEST_KEYCODE\x10\x01\x12\x14\n\x10RESPONSE_KEYCODE\x10\x02\x42\n\n\x08playload')
)



_LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE = _descriptor.EnumDescriptor(
  name='PingPacketType',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage.PingPacketType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PING_REQUEST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PING_RESPONSE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=595,
  serialized_end=648,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE)

_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE = _descriptor.EnumDescriptor(
  name='OtaPacketType',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaPacketType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQUEST_UPDATE_FIRMWARE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMIT_UPDATE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_UPDATE_DATA_SEND', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE_DATA_VERIFY', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_UPDATE_ABORT', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_COMPLETE_NOTIFY', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_STATUS_FAILD', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTA_STATUS_SUCCESS', index=7, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1089,
  serialized_end=1295,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE)

_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE = _descriptor.EnumDescriptor(
  name='FailCause',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.FailCause',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERASE_SECTION_FAILD', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_OFFSET_ERROR', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWITCH_SIGN_FAILD', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BRUN_UNFINISHED_ERROR', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1297,
  serialized_end=1406,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE)

_LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE = _descriptor.EnumDescriptor(
  name='UserDataType',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage.UserDataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='sendUsrDataToDev', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='getDevStatusData', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='sendStausDataToApp', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1546,
  serialized_end=1628,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE)

_LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE = _descriptor.EnumDescriptor(
  name='DevInfoType',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage.DevInfoType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQUEST_KEYCODE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESPONSE_KEYCODE', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1761,
  serialized_end=1817,
)
_sym_db.RegisterEnumDescriptor(_LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE)


_LOCALSERVERMESSAGE_PINGPACKETMESSAGE = _descriptor.Descriptor(
  name='PingPacketMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=648,
)

_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE = _descriptor.Descriptor(
  name='OtaUpdateDataMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='adr_offset', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage.adr_offset', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packet_length', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage.packet_length', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1086,
)

_LOCALSERVERMESSAGE_OTAPACKETMESSAGE = _descriptor.Descriptor(
  name='OtaPacketMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otafile_size', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.otafile_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ota_data', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.ota_data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cause', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.cause', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE, ],
  enum_types=[
    _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE,
    _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=1406,
)

_LOCALSERVERMESSAGE_USERDATAMESSAGE = _descriptor.Descriptor(
  name='UserDataMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usr_data', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage.usr_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1409,
  serialized_end=1628,
)

_LOCALSERVERMESSAGE_DEVINFOMESSAGE = _descriptor.Descriptor(
  name='DevinfoMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1817,
)

_LOCALSERVERMESSAGE = _descriptor.Descriptor(
  name='LocalServerMessage',
  full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='magic_num', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.magic_num', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localcode', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.localcode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='a', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.a', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.b', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.c', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='d', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.d', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LOCALSERVERMESSAGE_PINGPACKETMESSAGE, _LOCALSERVERMESSAGE_OTAPACKETMESSAGE, _LOCALSERVERMESSAGE_USERDATAMESSAGE, _LOCALSERVERMESSAGE_DEVINFOMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='playload', full_name='com.eufylife.smarthome.protobuftool.LocalServerMessage.playload',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=63,
  serialized_end=1829,
)

_LOCALSERVERMESSAGE_PINGPACKETMESSAGE.fields_by_name['type'].enum_type = _LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE
_LOCALSERVERMESSAGE_PINGPACKETMESSAGE.containing_type = _LOCALSERVERMESSAGE
_LOCALSERVERMESSAGE_PINGPACKETMESSAGE_PINGPACKETTYPE.containing_type = _LOCALSERVERMESSAGE_PINGPACKETMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE.containing_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE.fields_by_name['type'].enum_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE.fields_by_name['ota_data'].message_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE.fields_by_name['cause'].enum_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE.containing_type = _LOCALSERVERMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAPACKETTYPE.containing_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE
_LOCALSERVERMESSAGE_OTAPACKETMESSAGE_FAILCAUSE.containing_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE
_LOCALSERVERMESSAGE_USERDATAMESSAGE.fields_by_name['type'].enum_type = _LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE
_LOCALSERVERMESSAGE_USERDATAMESSAGE.containing_type = _LOCALSERVERMESSAGE
_LOCALSERVERMESSAGE_USERDATAMESSAGE_USERDATATYPE.containing_type = _LOCALSERVERMESSAGE_USERDATAMESSAGE
_LOCALSERVERMESSAGE_DEVINFOMESSAGE.fields_by_name['type'].enum_type = _LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE
_LOCALSERVERMESSAGE_DEVINFOMESSAGE.containing_type = _LOCALSERVERMESSAGE
_LOCALSERVERMESSAGE_DEVINFOMESSAGE_DEVINFOTYPE.containing_type = _LOCALSERVERMESSAGE_DEVINFOMESSAGE
_LOCALSERVERMESSAGE.fields_by_name['a'].message_type = _LOCALSERVERMESSAGE_PINGPACKETMESSAGE
_LOCALSERVERMESSAGE.fields_by_name['b'].message_type = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE
_LOCALSERVERMESSAGE.fields_by_name['c'].message_type = _LOCALSERVERMESSAGE_USERDATAMESSAGE
_LOCALSERVERMESSAGE.fields_by_name['d'].message_type = _LOCALSERVERMESSAGE_DEVINFOMESSAGE
_LOCALSERVERMESSAGE.oneofs_by_name['playload'].fields.append(
  _LOCALSERVERMESSAGE.fields_by_name['a'])
_LOCALSERVERMESSAGE.fields_by_name['a'].containing_oneof = _LOCALSERVERMESSAGE.oneofs_by_name['playload']
_LOCALSERVERMESSAGE.oneofs_by_name['playload'].fields.append(
  _LOCALSERVERMESSAGE.fields_by_name['b'])
_LOCALSERVERMESSAGE.fields_by_name['b'].containing_oneof = _LOCALSERVERMESSAGE.oneofs_by_name['playload']
_LOCALSERVERMESSAGE.oneofs_by_name['playload'].fields.append(
  _LOCALSERVERMESSAGE.fields_by_name['c'])
_LOCALSERVERMESSAGE.fields_by_name['c'].containing_oneof = _LOCALSERVERMESSAGE.oneofs_by_name['playload']
_LOCALSERVERMESSAGE.oneofs_by_name['playload'].fields.append(
  _LOCALSERVERMESSAGE.fields_by_name['d'])
_LOCALSERVERMESSAGE.fields_by_name['d'].containing_oneof = _LOCALSERVERMESSAGE.oneofs_by_name['playload']
DESCRIPTOR.message_types_by_name['LocalServerMessage'] = _LOCALSERVERMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocalServerMessage = _reflection.GeneratedProtocolMessageType('LocalServerMessage', (_message.Message,), dict(

  PingPacketMessage = _reflection.GeneratedProtocolMessageType('PingPacketMessage', (_message.Message,), dict(
    DESCRIPTOR = _LOCALSERVERMESSAGE_PINGPACKETMESSAGE,
    __module__ = 'LocalServerInfo_pb2'
    # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.PingPacketMessage)
    ))
  ,

  OtaPacketMessage = _reflection.GeneratedProtocolMessageType('OtaPacketMessage', (_message.Message,), dict(

    OtaUpdateDataMessage = _reflection.GeneratedProtocolMessageType('OtaUpdateDataMessage', (_message.Message,), dict(
      DESCRIPTOR = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE_OTAUPDATEDATAMESSAGE,
      __module__ = 'LocalServerInfo_pb2'
      # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage)
      ))
    ,
    DESCRIPTOR = _LOCALSERVERMESSAGE_OTAPACKETMESSAGE,
    __module__ = 'LocalServerInfo_pb2'
    # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.OtaPacketMessage)
    ))
  ,

  UserDataMessage = _reflection.GeneratedProtocolMessageType('UserDataMessage', (_message.Message,), dict(
    DESCRIPTOR = _LOCALSERVERMESSAGE_USERDATAMESSAGE,
    __module__ = 'LocalServerInfo_pb2'
    # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.UserDataMessage)
    ))
  ,

  DevinfoMessage = _reflection.GeneratedProtocolMessageType('DevinfoMessage', (_message.Message,), dict(
    DESCRIPTOR = _LOCALSERVERMESSAGE_DEVINFOMESSAGE,
    __module__ = 'LocalServerInfo_pb2'
    # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage.DevinfoMessage)
    ))
  ,
  DESCRIPTOR = _LOCALSERVERMESSAGE,
  __module__ = 'LocalServerInfo_pb2'
  # @@protoc_insertion_point(class_scope:com.eufylife.smarthome.protobuftool.LocalServerMessage)
  ))
_sym_db.RegisterMessage(LocalServerMessage)
_sym_db.RegisterMessage(LocalServerMessage.PingPacketMessage)
_sym_db.RegisterMessage(LocalServerMessage.OtaPacketMessage)
_sym_db.RegisterMessage(LocalServerMessage.OtaPacketMessage.OtaUpdateDataMessage)
_sym_db.RegisterMessage(LocalServerMessage.UserDataMessage)
_sym_db.RegisterMessage(LocalServerMessage.DevinfoMessage)


# @@protoc_insertion_point(module_scope)
